@@ -20,6 +20,8 @@ class Transformer(BaseTransformer):
         "6/31/09": datetime(2009, 6, 30),
         "N/A": None,
         "5/1820": datetime(2020, 5, 18),
+        "Starting": datetime(2023, 8, 21),
+        "4/10/23 (Updated 7/12/23)": datetime(2023, 4, 10),
     }
     jobs_corrections = {
         "700 *exact number pending relocation to other departments": 700,
@@ -51,6 +53,8 @@ class Transformer(BaseTransformer):
         "100 98 90": 90,
         "1 (Louisiana)": 1,
         "100 98 9087": 87,
+        "100 98 90 87": 87,
+        "TBD": None,
     }
 
     def transform_date(self, value: str) -> typing.Optional[str]:
