@@ -27,10 +27,26 @@ class Transformer(BaseTransformer):
     }
     date_corrections = {
         "TBA": None,
+        "TBD": None,
         "Temp layoff": None,
         "-": None,
         "3030-08-23 00:00:00": datetime(2020, 8, 23),
         "04/22/2022, 09/30/2022, 12/21/22": datetime(2022, 4, 22),
+        "08/15/2023, 8/22/2023": datetime(2024, 8, 15),
+        "7/7/23 - 08/23": datetime(2023, 7, 7),
+        "7/723 -  08/23": datetime(2023, 7, 7),
+        "7/7/23 - 8/2023": datetime(2023, 7, 7),
+        "7/723 -  8/2023": datetime(2023, 7, 7),
+        "10/23/2023 - 12/15/2023": datetime(2023, 10, 23),
+        "09/15/2023 - 12/06/2023": datetime(2023, 9, 15),
+        "09/30/2023 - 12/31/2023": datetime(2023, 9, 30),
+        "9/15/2023 - 12/06/2023": datetime(2023, 9, 15),
+        "9/30/2023 - 12/31/2023": datetime(2023, 9, 30),
+        "11/17/2023 - 12/01/2023": datetime(2023, 11, 17),
+        "11/15/2023 - 12/31/2023": datetime(2023, 11, 15),
+        "10/1/2023,10/31/2023,11/05/2023, 1/31/2024,1/1/2024,3/1/2024, 4/1/2024": datetime(
+            2023, 10, 1
+        ),
     }
 
     def transform_jobs(self, value: str) -> typing.Optional[int]:
